from distutils.core import setup

setup(
    name='event-emitter',
    packages=['haydn'],
    version='0.2.0',
    description='Javascript style event emitter for Python3',
    author='Jason Lee',
    url='https://bitbucket.org/haydn_team/event_emitter/',
    download_url='https://bitbucket.org/haydn_team/event_emitter.git'
)
